@@ -1,3 +1,9 @@
+"""
+MDL Mol Updating Utilities
+==========================
+
+"""
+
 import rdkit.Chem.AllChem as rdkit
 
 from stk.utilities import remake
