@@ -1,3 +1,9 @@
+"""
+XYZ Updating Utilities
+======================
+
+"""
+
 import numpy as np
 
 from stk.utilities import periodic_table
