@@ -4,15 +4,72 @@ M12L24
 
 """
 
-from ..cage import Cage
-from ..vertices import _NonLinearCageVertex, _LinearCageVertex
 from ...topology_graph import Edge
+from ..cage import Cage
+from ..vertices import LinearVertex, NonLinearVertex
 
 
 class M12L24(Cage):
     """
     Represents a cage topology graph.
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock(
+            smiles='[Pd+2]',
+            functional_groups=(
+                stk.SingleAtom(stk.Pd(0, charge=2))
+                for i in range(4)
+            ),
+            position_matrix=[[0, 0, 0]],
+        )
+
+        bb2 = stk.BuildingBlock(
+            smiles=(
+                'C1=NC=CC(C2=CC=CC(C3=C'
+                'C=NC=C3)=C2)=C1'
+            ),
+            functional_groups=[
+                stk.SmartsFunctionalGroupFactory(
+                    smarts='[#6]~[#7X2]~[#6]',
+                    bonders=(1, ),
+                    deleters=(),
+                ),
+            ],
+        )
+
+        cage = stk.ConstructedMolecule(
+            topology_graph=stk.cage.M12L24(
+                building_blocks=(bb1, bb2),
+            ),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cage.get_atoms(),
+                    cage.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=(
+                        1
+                        if bond.get_order() == 9
+                        else bond.get_order()
+                    ),
+                ) for bond in cage.get_bonds()
+            ),
+        )
+
     Metal building blocks with four functional groups are
     required for this topology.
 
@@ -33,47 +90,47 @@ class M12L24(Cage):
     """
 
     _vertex_prototypes = (
-        _NonLinearCageVertex(0, [1, 0, 0]),
-        _NonLinearCageVertex(1, [-1, 0, 0]),
-        _NonLinearCageVertex(2, [0, 1, 0]),
-        _NonLinearCageVertex(3, [0, -1, 0]),
-        _NonLinearCageVertex(4, [0.5, 0.5, 0.707]),
-        _NonLinearCageVertex(5, [0.5, -0.5, 0.707]),
-        _NonLinearCageVertex(6, [-0.5, 0.5, 0.707]),
-        _NonLinearCageVertex(7, [-0.5, -0.5, 0.707]),
-        _NonLinearCageVertex(8, [0.5, 0.5, -0.707]),
-        _NonLinearCageVertex(9, [0.5, -0.5, -0.707]),
-        _NonLinearCageVertex(10, [-0.5, 0.5, -0.707]),
-        _NonLinearCageVertex(11, [-0.5, -0.5, -0.707]),
+        NonLinearVertex(0, [1, 0, 0]),
+        NonLinearVertex(1, [-1, 0, 0]),
+        NonLinearVertex(2, [0, 1, 0]),
+        NonLinearVertex(3, [0, -1, 0]),
+        NonLinearVertex(4, [0.5, 0.5, 0.707]),
+        NonLinearVertex(5, [0.5, -0.5, 0.707]),
+        NonLinearVertex(6, [-0.5, 0.5, 0.707]),
+        NonLinearVertex(7, [-0.5, -0.5, 0.707]),
+        NonLinearVertex(8, [0.5, 0.5, -0.707]),
+        NonLinearVertex(9, [0.5, -0.5, -0.707]),
+        NonLinearVertex(10, [-0.5, 0.5, -0.707]),
+        NonLinearVertex(11, [-0.5, -0.5, -0.707]),
 
-        _LinearCageVertex(12, [0.9, 0.31, 0.31], False),
-        _LinearCageVertex(13, [0.9, 0.31, -0.31], False),
-        _LinearCageVertex(14, [0.9, -0.31, 0.31], False),
-        _LinearCageVertex(15, [0.9, -0.31, -0.31], False),
+        LinearVertex(12, [0.9, 0.31, 0.31], False),
+        LinearVertex(13, [0.9, 0.31, -0.31], False),
+        LinearVertex(14, [0.9, -0.31, 0.31], False),
+        LinearVertex(15, [0.9, -0.31, -0.31], False),
 
-        _LinearCageVertex(16, [-0.9, 0.31, 0.31], False),
-        _LinearCageVertex(17, [-0.9, 0.31, -0.31], False),
-        _LinearCageVertex(18, [-0.9, -0.31, 0.31], False),
-        _LinearCageVertex(19, [-0.9, -0.31, -0.31], False),
+        LinearVertex(16, [-0.9, 0.31, 0.31], False),
+        LinearVertex(17, [-0.9, 0.31, -0.31], False),
+        LinearVertex(18, [-0.9, -0.31, 0.31], False),
+        LinearVertex(19, [-0.9, -0.31, -0.31], False),
 
-        _LinearCageVertex(20, [0.31, 0.9, 0.31], False),
-        _LinearCageVertex(21, [0.31, 0.9, -0.31], False),
-        _LinearCageVertex(22, [-0.31, 0.9, 0.31], False),
-        _LinearCageVertex(23, [-0.31, 0.9, -0.31], False),
+        LinearVertex(20, [0.31, 0.9, 0.31], False),
+        LinearVertex(21, [0.31, 0.9, -0.31], False),
+        LinearVertex(22, [-0.31, 0.9, 0.31], False),
+        LinearVertex(23, [-0.31, 0.9, -0.31], False),
 
-        _LinearCageVertex(24, [0.31, -0.9, 0.31], False),
-        _LinearCageVertex(25, [0.31, -0.9, -0.31], False),
-        _LinearCageVertex(26, [-0.31, -0.9, 0.31], False),
-        _LinearCageVertex(27, [-0.31, -0.9, -0.31], False),
+        LinearVertex(24, [0.31, -0.9, 0.31], False),
+        LinearVertex(25, [0.31, -0.9, -0.31], False),
+        LinearVertex(26, [-0.31, -0.9, 0.31], False),
+        LinearVertex(27, [-0.31, -0.9, -0.31], False),
 
-        _LinearCageVertex(28, [0.58, 0, 0.82], False),
-        _LinearCageVertex(29, [-0.58, 0, 0.82], False),
-        _LinearCageVertex(30, [0, 0.58, 0.82], False),
-        _LinearCageVertex(31, [0, -0.58, 0.82], False),
-        _LinearCageVertex(32, [0.58, 0, -0.82], False),
-        _LinearCageVertex(33, [-0.58, 0, -0.82], False),
-        _LinearCageVertex(34, [0, 0.58, -0.82], False),
-        _LinearCageVertex(35, [0, -0.58, -0.82], False),
+        LinearVertex(28, [0.58, 0, 0.82], False),
+        LinearVertex(29, [-0.58, 0, 0.82], False),
+        LinearVertex(30, [0, 0.58, 0.82], False),
+        LinearVertex(31, [0, -0.58, 0.82], False),
+        LinearVertex(32, [0.58, 0, -0.82], False),
+        LinearVertex(33, [-0.58, 0, -0.82], False),
+        LinearVertex(34, [0, 0.58, -0.82], False),
+        LinearVertex(35, [0, -0.58, -0.82], False),
     )
 
     _edge_prototypes = (
