@@ -21,11 +21,11 @@ class TwoPlusFour(Cage):
         import stk
 
         bb1 = stk.BuildingBlock(
-            smiles='BrCCBr',
+            smiles='C1=CC=C(C(=C1)Br)Br',
             functional_groups=[stk.BromoFactory()],
         )
         bb2 = stk.BuildingBlock(
-            smiles='Brc1c(Br)cc(Br)c(Br)c1',
+            smiles='C1(=C(C(=C1Br)Br)Br)Br',
             functional_groups=[stk.BromoFactory()],
         )
         cage = stk.ConstructedMolecule(
@@ -59,11 +59,11 @@ class TwoPlusFour(Cage):
         import stk
 
         bb1 = stk.BuildingBlock(
-            smiles='BrCCBr',
+            smiles='C1=CC=C(C(=C1)Br)Br',
             functional_groups=[stk.BromoFactory()],
         )
         bb2 = stk.BuildingBlock(
-            smiles='Brc1c(Br)cc(Br)c(Br)c1',
+            smiles='C1(=C(C(=C1Br)Br)Br)Br',
             functional_groups=[stk.BromoFactory()],
         )
         cage = stk.ConstructedMolecule(
