@@ -14,6 +14,7 @@ import os
 import re
 import tarfile
 import time
+import typing
 from collections import deque
 from contextlib import contextmanager
 
@@ -81,6 +82,10 @@ periodic_table = {
 }
 
 
+T = typing.TypeVar('T')
+OneOrMany = typing.Union[T, typing.Iterable[T]]
+
+
 class Cell:
     """
     Represents an individual cell in a supercell.
